Learn R Programming

rbsurv (version 2.30.0)

gliomaSet: Gene expression and survival data of the patients with gliomas

Description

These data sets consist of gene expression and survival of the patients with gliomas. Note that it contains a subset of the data published in Freije et al. (2004).

Arguments

Freije et al. (2004). Gene Expression Profiling of Gliomas Strongly Predicts Survival, Cancer Research, 64: 6503-6510.